@@ -1,7 +1,10 @@
+## ----setup, include=FALSE------------------------------------------------
+knitr::opts_chunk$set(tidy = TRUE)
+
 ## ----eval=FALSE----------------------------------------------------------
 #  install.packages('formatR', repos = 'http://cran.rstudio.com')
 #  #' to install the development version, run
-#  #' install.packages('formatR', repos = 'http://rforge.net')
+#  #' install.packages('formatR', repos = 'http://yihui.name/xran')
 
 ## ------------------------------------------------------------------------
 library(formatR)
